******************************************************************************* 
*
* If iform = 0, this script plots a best track with the data copied from 
* <http://weather.unisys.com/hurricane/atlantic> in the format: 
* 
*   9  11.00  -53.70 07/13/00Z   45  1003 TROPICAL STORM
*  15  12.40  -63.20 07/14/12Z   85   980 HURRICANE-2
* 
* If iform = 1, this script plots a forecast track with data in the format: 
* 
* 2005082600   6  0  0  -81.21536  25.69806  984.613  64.314  38.619  80.063
* 2005082600  12  0  1  -81.98824  25.32888  977.146  81.411  58.252  53.375
* 2005082600  18  0  0  -82.67487  24.96762  970.339  84.992  61.850  46.703
* 
* If iform = 2, this script plots a track with data in revised ATCF format: 
* 
* EP  04  2010061912  03  HWRF  000  12.8  -97.0   28  1006  XX
* EP  04  2010061912  03  HWRF  006  12.6  -97.6   37   998  XX
* EP  04  2010061912  03  HWRF  012  12.5  -98.0   39   999  XX
* 
* USAGE: plot_track  file    iform    istart   iend    <incr> 
*                   <imark> <icolor> <istyle> <ithick> <marksz> 
* 
*        file   = data filename 
*        iform  = data format (0/1: best_track/fcst_track) 
*        istart = starting  number of record to be plotted 
*        iend   =  ending   number of record to be plotted 
*        incr   = increment number of record to be plotted 
*        imark  = number for the mark  of storm center 
*        icolor = number for the color of track line 
*        istyle = number for the style of track line 
*        ithick = number for thickness of track line 
*        makrsz = size of the mark diameter in inches 
* 
*        imark  = -1: open hurricane symbol without track lines 
*        imark  =  0: open circle (and x if bad) without track lines 
*        <****> = optional argument 
* 
*------------------------------------------------------------------------------ 

FUNCTION track(args)

file   = subwrd(args,1)
iform  = subwrd(args,2)
istart = subwrd(args,3)
iend   = subwrd(args,4)
incr   = subwrd(args,5)
imark  = subwrd(args,6)
icolor = subwrd(args,7)
istyle = subwrd(args,8)
ithick = subwrd(args,9)
marksz = subwrd(args,10)

IF ( iform  = '0' ) ; ilon = 3 ; ilat = 2 ; ibad = 5 ; ENDIF
IF ( iform  = '1' ) ; ilon = 5 ; ilat = 6 ; ibad = 4 ; ENDIF
IF ( iform  = '2' ) ; ilon = 8 ; ilat = 7 ; ibad = 9 ; ENDIF
IF ( incr   = ''  ) ; incr   =   1  ; ENDIF
IF ( icolor = ''  ) ; icolor =   9  ; ENDIF
IF ( istyle = ''  ) ; istyle =   1  ; ENDIF
IF ( ithick = ''  ) ; ithick =  12  ; ENDIF
IF ( imark  = '-1') 
   type = 'wxsym'   ; jmark  =  40 
   IF ( marksz='' ) ; marksz = 0.15 ; ENDIF 
ELSE
   type = 'mark'    ; jmark  = imark
   IF ( imark ='0') ; jmark  =   2  ; ENDIF
   IF ( imark ='' ) ; jmark  =   3  ; ENDIF
   IF ( marksz='' ) ; marksz = 0.06 ; ENDIF 
ENDIF

'set line 'icolor' 'istyle' 'ithick 

 i = 1 
ii = istart - incr
WHILE ( i <= iend )

  reading =  read(file)
  record = sublin(reading,2)
   alon  = subwrd(record,ilon)
   blat  = subwrd(record,ilat)
   mbad  = subwrd(record,ibad)

   IF ( i - ii = incr )

     'query ll2xy 'alon' 'blat 
      coord = sublin(result,1)
      xpage = subwrd(coord,1)
      ypage = subwrd(coord,2)

     'draw 'type' 'jmark' 'xpage' 'ypage' 'marksz' 'icolor' 'ithick 

      IF ( i > istart & imark > 0 ) 
     'draw line 'x_old' 'y_old' 'xpage' 'ypage 
      ENDIF

      IF ( imark = 0 & mbad = 1 )
     'draw  mark     6    'xpage' 'ypage' 'marksz 
      ENDIF

      say '  Storm centered at (lon, lat) = 'alon' 'blat 
      x_old = xpage
      y_old = ypage
      ii = i

   ENDIF

   i = i + 1 

ENDWHILE 

RETURN

*============================================================================== 
